@@ -1,4 +1,4 @@
 from tltk import nlp
 from tltk import corpus
-from tltk.nlp import initial, word_segment, word_segment_mm, syl_segment, word_segment_nbest, read_thaidict, reset_thaidict, check_thaidict, spell_candidates, spell_variants, pos_tag, pos_tag_wordlist, segment, chunk, ner, ner_tag, g2p, th2ipa, th2roman, g2p_all, WordAna, TextAna, SylAna, th2read
+from tltk.nlp import initial, word_segment, word_segment_mm, syl_segment, word_segment_nbest, read_thaidict, reset_thaidict, check_thaidict, spell_candidates, spell_variants, pos_tag, pos_tag_wordlist, segment, chunk, ner, ner_tag, g2p, th2ipa, th2roman, th2ipa_all, WordAna, TextAna, SylAna, th2read, TNC_tag, TextAna2json
 from tltk.corpus import TNC_load, trigram_load, bigram, trigram, unigram, collocates, w2v_load, w2v_exist, w2v, w2v_plot, similarity, cosine_similarity, similar_words, outofgroup, analogy, w2v_compare_color, Corpus_build, W2V_train, D2V_train, W2V_load, Corpus, Xwordlist, download_TNCw2v, download_TNC3g
